bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 23. Aventiure
___________________________________________________
| ### <Mit> vil grozen eren daz ist al war ### wonten si mit ein ander vnz an daz sibende iar ### di zit div chveneginne eines svns was genesen ### des chvnde der kvenich Ecel nimmer vroelicher wesen ### Sine wolde niht erwinden sine werbe sint ### daz getovffet werde daz Eceln chint ### nach cristenlichem rehte ez wart Ortliep genant ### des wart vil michel frevde vber elliv Eceln lant
###### 1386 | ### Swaz ie gvter tvgende an vrovn Helchen lach ### der vleiz sich nv vrov Criemhilt dar nach vil manigen tach ### di site si lerte Herrat div ellende meit ### div hete tovgenliche nach Helchen groziv leit
| ### Den vremden vnt den chvnden was si vil wol bechant ### di iahen daz nie vrowe besæze ein kveneges lant ### bezzer vnde milter daz heten si fver war ### daz lop si trvch si cen Hivnen vnz an daz dricehende iar
###### 1388 | ### Nv het si wol erchvnnen daz ir niemen widerstvnt ### also noch fvrsten wibe chveneges recken tvnt ### vnt daz si alle zite zwelf chvenige vor ir sach ### si gedaht ovch maniger leide der ir da heime gesach
###### 1389 | ### Si gedaht ovch maniger eren von Nibelvnge lant ### der si da was <gewaltich> vnt di ir Hagenen hant ### mit Sifrides tode hete gar benomen ### ob im daz noch immer von ir ce leide mohte chomen
| ### S <Daz> geschæhe ob ich in moehte bringen in daz lant ### ir trovmte daz ir gienge vil diche an der hant ### Giselher ir brvder si chvsten zaller stvnt ### vil ofte in senftem slaffe sit wart in arbeiten chvnt
###### 1391 | ### Ich wæne der vbel valant Criemhilde daz geriet ### daz si sich mit frivntschefte von Giselhere schiet ### den si dvrch svne chvste in Bvergonden lant ### do begonde ir aber salwen von heizen trehen ir gewant
###### 1392 | ### Ez lag ir an dem hercen spate vnd vrov ### wi man si ane schvlde bræhte dar zv ### daz si mvese minnen einen heidenisschen man ### di not di het ir Hsagene vnt Gvnther getan [359b]
| ### Des willen in ir hercen chom si vil selten abe ### <si> gedahte ich pin so riche vnt han so groze habe ### daz ich minen vinden gefvege noch ein leit ### des wære et ich von Tronege Hagen gerne bereit
###### 1394 | ### Nach den getriwen iamert diche daz herce min ### di mir da leide taten moehte ich pi den sin ### so werde wol errochen mines vrivndes lip ### des ich chvme erbeite sprach daz Ecelen wip
###### 1395 | ### Ze liebe si do heten alle skveneges man ### di Criemhilde recken daz was vil wol getan ### der chamern der pflach Eckewart da von er frivnt gewan ### den Crimhilde willen chvnde niemen vnderstan
| ### Si dahte zallen ziten ich wil den chvenech piten ### daz er ir des gonde mit gvetlichen siten ### daz man ir frivnde bræhte in der Hivnen lant ### den argen willen niemen an der chvneginn ervant
###### 1397 | ### Do si eines nahtes bi dem chvenige lach ### mit armen vmbvangen het er si als er pflach ### di edeln vrowen trivten si was im also sin lip ### do gedahte ir finde daz vil herliche wip
###### 1398 | ### Si sprach zv dem chvenige vil lieber herre min ### ich wolde ivch bitten gerne moht iz mit hvlden sin ### daz ir mich liezet sehen ob ich daz het versolt ### ob ir den minen vrivnden wæret innechlichen holt
| ### Do sprach der kvenich riche getriwe was sin mvt ### ich bringe ivch des wol innen swa lip vnd gvt ### den recken widerfvere des mvese ich frevde han ### wande ich von wibes minne nie bezer frivnde gewan
###### 1400 | ### Do sprach div chveneginne iv ist daz wol geseit ### ich han vil hoher mage dar vmbe ist mir so leit ### daz mich di so selten rvchent hie gesehen ### ich hoere min di livte niwan fver ellende iehen
###### 1401 | ### Do sprach der chvenech Ecel vil liebiv vrowe min ### divht ez si niht ce verre so lvede ich veber Rin ### swelhe ir da gerne sæhet her in miniv lant ### des vrevete sich div vrowe do si den willen sin ervant
| ### Si sprach welt ir mir triwe leisten herre min ### so svlt ir boten senden ce Wormez veber Rin ### so enbivt ich [360a] minen frivnden des ich da habe mvt ### so chvmt vns her ce lande vil manich edel ritter gvt
###### 1403 | ### Er sprach <swenne> ir gebietet so lazet ez geschehen ### irn chvndet iwer vrivnde so gerne niht gesehen ### als ich si gesæhe der edeln Vten chint ### mich mweet daz harte sere daz si vns so lange vremde sint
###### 1404 | ### Ob ez dir wol gevalle vil liebiv vrowe min ### so wold ich gerne senden nach den frivnden din ### di minen videlære in Bvergonden lant ### di gvten videlære hiez er bringen sa cehant
| ### Si ilten harte balde da der kvenech saz ### bi der chveneginne er saget in beiden daz ### si solden poten werden in Bvergonden lant ### do hiez er in bereiten harte herlich gewant
###### 1406 | ### Vier vnd zweinzech recken bereite man div chleit ### ovch wart in von dem chvenege div boteschaft geseit ### wi si dar laden solden Gventher vnd sine man ### Criemhilt div vrowe si svnder sprechen began
###### 1407 | ### Do sprach der kvenech riche irh sage iv wi ir tvt ### ich enbivte minen vrivnden liep vnde allez gvt ### daz si gervchen ritten her in miniv lant ### ich han so lieber geste harte wenich noch bechant
| ### Vnde ov si mines willen wellen iht began ### di Criemhilde mage daz si des niht en lan ### sine chomen an disem svmere zv miner hohgecit ### wand vil der minen wenne an minen chonemagen lit
###### 1409 | ### Do sprach der videlære der stolze Swemmelin ### wenne sol iwer hohzit in disen landen sin ### daz wir daz ivren frivnden chvnnen dort gesagen ### do sprach der kvenech Ecel ce næhsten svnewenden tagen
###### 1410 | ### Wir tvn swaz ir gebietet sprach do Wærbelin ### in ir chemnaten bat si div chvenegin ### bringen tovgenliche da si di boten sprach ### da von vil manigem degene sit wenich liebes gesach
| ### Si sprach cen boten beiden nv dienet michel gvt ### daz ir minen willen vil gvetlichen tvt ### vnd saget swaz ich enbiete heim in vnser lant ### ich mache ivch gvtes riche vnt gip iv herlich gewant
###### 1412 | ### Vnde swaz ir miner frivnde immer mvget gesehen ### ze Wormez bi dem Rine [360b] den svlt ir niht veriehen ### daz ir noch nie gesæhet betrvebet minen mvt ### vnt saget minen dienest den helden chvene vnde gvt
###### 1413 | ### Bittet daz si lesten daz in Rvedger enbot ### vnt mich da mite scheiden von aller miner not ### di Hivnen wellent wænen deich ane vrivnde si ### ob ich ein ritter wære ich chom in etwenne bi
| ### Vnde sagt ovch Gernot dem edelen brvder min ### daz im zer werlde holder niemen mvege sin ### bittet daz er mir bringe in diz lant ### vnser besten frivnde deiz vns cen eren si gewant
###### 1415 | ### So sagt ovch Giselher daz er wol gedenche dar an ### daz ich von sinen schvlden nie leides niht gewan ### des sæhen in vil gerne hie div ovgen min ### ich heten in hie vil gerne dvrch di grozen triwe sin
###### 1416 | ### Sagt ovch miner mvter di ere di ich han ### vnd ob von Tronege Hagene welle dort bestan ### wer si danne sold wisen dvrch <div> lant ### dem sint di wege von chinde her cen Hivnen wol bechant
| ### Di boten nine westen wa von daz was getan ### daz si von Tronege Hagen niht solden lan ### beliben bi dem Rine ez wart in sider leit ### mit im was manigem degene ze grimmem tode widerseit
###### 1418 | ### Brieve vnde botschaft was in nv gegeben ### si fvren gvtes riche vnd mohten schone leben ### vrlovb gap in Ecel vnd ovch sin schoene wip ### in was von gvter wæte wol gezieret der lip

<<< Übersicht <<< vorige Seite nächste Seite >>>